@@ -57,20 +57,16 @@ sub create {
     my $self = shift;
 
     my $payload = encode_json({description => $self->description, name => $self->name});
-    my $response = $self->fdb->post(
-        path    => $self->abs_path('namespaces', $self->path_of_parent),
-        headers => $self->fdb->headers_for_json,
-        payload => $payload
+    $self->fdb->post(
+        path       => $self->abs_path('namespaces', $self->path_of_parent),
+        headers    => $self->fdb->headers_for_json,
+        payload    => $payload,
+        on_success => sub {
+            my $response = shift;
+            my $h = decode_json($response->content);        
+            $self->_set_object_id($h->{id});
+        }
     );
-
-    if ($response->is_success) {
-        my $h = decode_json($response->content);        
-        $self->_set_object_id($h->{id});
-        1;
-    } else {
-        print STDERR $response->content, "\n";
-        0;
-    }
 }
 
 sub get {
@@ -79,24 +75,21 @@ sub get {
     foreach my $key (qw(description namespaces tags)) {
         $opts{"return\u$key"} = 1 if delete $opts{$key};    
     }
-    my $response = $fdb->get(
-        path    => $class->abs_path('namespaces', $path),
-        query   => \%opts,
-        headers => $fdb->accept_header_for_json
+    $fdb->get(
+        path       => $class->abs_path('namespaces', $path),
+        query      => \%opts,
+        headers    => $fdb->accept_header_for_json,
+        on_success => sub {
+            my $response = shift;
+            my $h = decode_json($response->content);
+            my $ns = $class->new(fdb => $fdb, path => $path);
+            $ns->_set_object_id($h->{id});
+            $ns->description($h->{description})             if $opts{returnDescription};
+            $ns->_set_namespace_names($h->{namespaceNames}) if $opts{returnNamespaces};
+            $ns->_set_tag_names($h->{tagNames})             if $opts{returnTags};
+            $ns;            
+        }
     );
-
-    if ($response->is_success) {
-        my $h = decode_json($response->content);
-        my $ns = $class->new(fdb => $fdb, path => $path);
-        $ns->_set_object_id($h->{id});
-        $ns->description($h->{description})             if $opts{returnDescription};
-        $ns->_set_namespace_names($h->{namespaceNames}) if $opts{returnNamespaces};
-        $ns->_set_tag_names($h->{tagNames})             if $opts{returnTags};
-        $ns;
-    } else {
-        print STDERR $response->content, "\n";
-        0;
-    }
 }
 
 # Normal usage is to set description and path of self.
@@ -104,29 +97,17 @@ sub update {
     my $self = shift;
 
     my $payload = encode_json({description => $self->description});
-    my $response = $self->fdb->put(
+    $self->fdb->put(
         path    => $self->abs_path('namespaces', $self->path),
         headers => $self->fdb->headers_for_json,
         payload => $payload
     );
-
-    if ($response->is_success) {
-        1;        
-    } else {
-        print STDERR $response->content, "\n";
-        0;
-    }
 }
 
 sub delete {
     my $self = shift;
-    my $response = $self->fdb->delete(path => $self->abs_path('namespaces', $self->path));
-    if ($response->is_success) {
-        1;
-    } else {
-        print STDERR $response->content, "\n";
-        0;
-    }    
+
+    $self->fdb->delete(path => $self->abs_path('namespaces', $self->path));
 }
 
 no Moose;
